@@ -418,7 +418,9 @@ class Model:
         for sizetable in sizetables:
             for style in styles:
                 if style.row == sizetable[0]:
+                    print(sizetable[1])
                     for n in range(sizetable[1]):
+                        print(n)
                         self.__styles.append(Style(style.name,style.row+n,style.column,style.data_type, style.font, style.alignment,style.fill, style.border))
         for style in self.styles:
             style.rename()
